OC.L10N.register(
    "core",
    {
    "Please select a file." : "Изберете датотека.",
    "File is too big" : "Датотеката е пре голема",
    "The selected file is not an image." : "Избраната датотека не е слика.",
    "The selected file cannot be read." : "Избраната датотека неможе да се прочита.",
    "The file was uploaded" : "Датотеката е прикачена",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која е одредена во HTML формата",
    "The file was only partially uploaded" : "Датотеката е само делумно прикачена",
    "No file was uploaded" : "Нема прикачено дадотека",
    "Missing a temporary folder" : "Недостасува привремена папка",
    "Could not write file to disk" : "Неможе да се запишува на дискот",
    "A PHP extension stopped the file upload" : "PHP додаток го стопираше прикачувањето на датотеката",
    "Invalid file provided" : "Дадена е невалидна датотека",
    "No image or file provided" : "Не е доставена фотографија или датотека",
    "Unknown filetype" : "Непознат тип на датотека",
    "An error occurred. Please contact your admin." : "Настана грешка. Контактирате со администраторот.",
    "Invalid image" : "Невалидна фотографија",
    "No temporary profile picture available, try again" : "Не е достапна привремена профилна слика, пробајте повторно",
    "No crop data provided" : "Не се доставени податоци за сечење",
    "No valid crop data provided" : "Нема валидни податоци за сечење",
    "Crop is not square" : "Сечењето не е квадратно",
    "State token does not match" : "Токенот не се совпаѓа",
    "Invalid app password" : "Погрешна лозинка за апликација",
    "Could not complete login" : "Неможе да се комплетира најавувањето",
    "Your login token is invalid or has expired" : "Вашиот токен за најава е невалиден или истечен",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Оваа верзија повеќе не е поддржана и Push известувањата се ограничени.",
    "Login" : "Најава",
    "Password reset is disabled" : "Ресетирање на лозинката е оневозможено",
    "Could not reset password because the token is expired" : "Неможе да се промени лозинката бидејќи токенот е истечен",
    "Could not reset password because the token is invalid" : "Неможе да се промени лозинката бидејќи токенот е невалиден",
    "%s password reset" : "%s ресетирање на лозинката",
    "Password reset" : "Ресетирај лозинка",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете на следното копче за да ја ресетирате вашата лозинка. Доколку не сте побарале ресетирање на лозинка, игнорирајте ја оваа порака.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Кликнете на следниот линк за да ја ресетирате вашата лозинка. Доколку не сте побарале ресетирање на лозинка, игнорирајте ја оваа порака.",
    "Reset your password" : "Ресетирај ја твојата лозинка",
    "Task not found" : "Задачата не е пронајдена",
    "Internal error" : "Внатрешна грешка",
    "Image not found" : "Сликата не е пронајдена",
    "Could not detect language" : "Неможе да се детектира јазикот",
    "Unable to translate" : "Неможе да се преведе",
    "Nextcloud Server" : "Nextcloud Сервер",
    "Some of your link shares have been removed" : "Некој од вашите линкови што ги споделивте се избришани",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради безбедносен ризик некој од вашите споделувања се избришани. Ве молиме видете го линкот за повеќе информации.",
    "Learn more ↗" : "Научи повеќе ↗",
    "Preparing update" : "Ја подготвувам надградбата",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Чекори за поправка:",
    "Repair info:" : "Инфо при поправка:",
    "Repair warning:" : "Предупредувања при поправка:",
    "Repair error:" : "Грешка при поправка:",
    "Turned on maintenance mode" : "Вклучен е модот за одржување",
    "Turned off maintenance mode" : "Ислкучен е модот за одржување",
    "Maintenance mode is kept active" : "Модот за одржување е уште активен",
    "Updating database schema" : "Ја надградувам шемата на базата на податоци",
    "Updated database" : "Базата е надградена",
    "Update app \"%s\" from App Store" : "Ажурирање на апликација \"%s\" од продавницата",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Проверка дали шемата на базата на податоци %s може да се ажурира (ова може да трае долго време во зависност од големината на базата на податоци)",
    "Updated \"%1$s\" to %2$s" : "Ажурирано \"%1$s\" во %2$s",
    "Set log level to debug" : "Постави го нивото на записи на откривање на грешки",
    "Reset log level" : "Ресетирај го нивото на записи",
    "Starting code integrity check" : "Стартува проверка на интегритетот на кодот",
    "Finished code integrity check" : "Заврши проверката на интегритетот на кодот",
    "%s (incompatible)" : "%s (некомпатибилен)",
    "The following apps have been disabled: %s" : "Следниве апликации се оневозможени: %s",
    "Already up to date" : "Веќе ажурирано",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Вашиот веб опслужувач сеуште не е точно подесен да овозможува синхронизација на датотеки бидејќи интерфејсот за WebDAV изгледа дека е расипан. ",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Вашиот веб сервер не е правилно поставен за разрешаување на \"{url}\".  Повеќе информации можат да се пронајдат во {linkstart}документацијата ↗{linkend}.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Пристапувате на оваа истанца преку безведносна врска, но оваа истанца генерира не-безбедни URL адреси. Ова, најверојатно, значи дека стоите зад обратниот прокси и променливите за конфигурирање за пребришување не се правилно поставени. Прочитајде во {linkstart}документацијата{linkend}.",
    "Error occurred while checking server setup" : "Се случи грешка при проверката на параметрите на серверот",
    "For more details see the {linkstart}documentation ↗{linkend}." : "За повеќе детали погледнете во {linkstart}документацијата ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вашата папка за податоци и вашите датотеки се најверојатно достапни од интернет. Датотеката .htaccess не работи. Строго ви препорачуваме да го подесите вашиот веб опслужувач на начин на кој вашата папка за податоци не е веќе достапна од интернет или да ја преместите папката за податоци надвор од коренот на веб опслужувачот.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавието \"{header}\" не е поставено да биде \"{expected}\". Ова потенцијално може да ја загрози приватноста и безбедноста, се препорачува соодветно да ја поставите оваа поставка.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "HTTP заглавието \"{header}\" не е поставено да биде \"{expected}\". Некои карактеристики може да не функционираат правилно, се препорачува соодветно да ја поставите оваа поставка.",
    "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP заглавието \"{header}\" не го содржи \"{expected}\". Ова потенцијално може да ја загрози приватноста и безбедноста, се препорачува соодветно да ја поставите оваа поставка.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP заглавието \"{header}\" не е поставено да биде \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" или \"{val5}\". Ова може да открие сигурносни информации. Погледнете {linkstart}Препораки за W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "\"Strict-Transport-Security\" HTTP насловот не е поставен на мнајмалку \"{seconds}\" секунди. За подобрена безбедност, се препорачува да се овозможи HSTS како што е опишано во {linkstart}совети за безбедност ↗{linkend}.",
    "unknown text" : "непознат текст",
    "Hello world!" : "Здраво свету!",
    "sunny" : "сончево",
    "Hello {name}, the weather is {weather}" : "Здраво {name}, времето е {weather}",
    "Hello {name}" : "Здраво {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Ова се вашите резултати од пребарувањето<script>alert(1)</script></strong>",
    "new" : "ново",
    "_download %n file_::_download %n files_" : ["преземи 1 датотека","преземи %n датотеки"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Во тек е надградба на системот, доколку ја напуштите оваа страница може да дојде до прекин на некој процес во некој дел.",
    "Update to {version}" : "Надгради на {version}",
    "An error occurred." : "Се случи грешка",
    "Please reload the page." : "Превчитајте ја страницата.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Надградбата не беше успешна. За повеќе информации <a href=\"{url}\">проверете го нашиот форум</a> што го покрива овој проблем.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Надградбата не беше успешна. Ве молиме овој проблем да го пријавите во <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">заедницата</a>.",
    "Continue to {productName}" : "Продолжи кон {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Ажурирањето беше успешно. Пренасочување кон {productName} за %n секунда.","Ажурирањето беше успешно. Пренасочување кон {productName} за %n секунди."],
    "More apps" : "Повеќе апликации",
    "Currently open" : "Моментално отворено",
    "_{count} notification_::_{count} notifications_" : ["Едно исзестување","{count} известувања"],
    "Pick start date" : "Избери почетен датум",
    "Pick end date" : "Избери краен датум",
    "Log in" : "Најава",
    "Logging in …" : "Најава ...",
    "Server side authentication failed!" : "Автентификацијата на серверската страна е неуспешна!",
    "Please contact your administrator." : "Ве молиме контактирајте го вашиот администратор.",
    "Please try again." : "Ве молиме обидете се повторно.",
    "An internal error occurred." : "Се случи внатрешна грешка.",
    "Please try again or contact your administrator." : "Ве молиме обидете се повторно или контактирајте го вашиот администратор.",
    "Password" : "Лозинка",
    "Log in to {productName}" : "Најави се на {productName}",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Детектирани се повеќе неуспешни најавувања од вашата IP адреса. Затоа вашиот следен обид за најавување е одложено за 30 секунди.",
    "Log in with a device" : "Најавете се со уред",
    "Your account is not setup for passwordless login." : "Вашата сметка не е поставена за најавување без лозинка.",
    "Browser not supported" : "Вашиот прелистувач не е поддржан",
    "Passwordless authentication is not supported in your browser." : "Вашиот прелистувач не поддржува автентикација без лозинка.",
    "Your connection is not secure" : "Конекцијата не е безбедна",
    "Passwordless authentication is only available over a secure connection." : "Автентикација без лозинка е достапно доколку користите безбедна конекција.",
    "Reset password" : "Ресетирај лозинка",
    "Couldn't send reset email. Please contact your administrator." : "Не можам да истпратам порака за ресетирање. Ве молам контактирајте го вашиот администратор.",
    "Password cannot be changed. Please contact your administrator." : "Лозинката не може да се промени. Ве молам контактирајте го вашиот администратор.",
    "Back to login" : "Врати се на страната за најавување",
    "New password" : "Нова лозинка",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Вашите податоци се шифрирани. Не постои можност за враќање на податоците одкако вашата лозинка ќе биде ресетирана. Доколку незнаете што да правите, контактирајте го вашиот администратор пред да продолжите понатаму. Дали сте сигурни дека сакате да продолжите?",
    "I know what I'm doing" : "Знам што правам",
    "Resetting password" : "Ресетирање на лозинка",
    "Recommended apps" : "Препорачани апликации",
    "Loading apps …" : "Апликациите се вчитуваат ...",
    "Could not fetch list of apps from the App Store." : "Неможе да се вчита листата на апликации од продавницата.",
    "Installing apps …" : "Инсталирање на апликации ...",
    "App download or installation failed" : "Неуспешно преземање или инсталирање на апликација",
    "Cannot install this app because it is not compatible" : "Неможе да се инсталираа оваа апликација бидејќи не е компатибилна",
    "Cannot install this app" : "Неможе да се инсталираа оваа апликација ",
    "Skip" : "Прескокни",
    "Install recommended apps" : "Инсталирајте ги препорачаните апликации",
    "Schedule work & meetings, synced with all your devices." : "Работни задачи & состаноци, синхронизирани со сите ваши уреди.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Чувајте ги вашите колеги и пријатели на едно место без да ги разоткривате нивните приватни информации.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Едноставна апликација за е-пошта интегрирана со Датотеки, Контакти, Календар.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Разговори, видео повици, споделување на екранот, онлајн состаноци и веб конференции - на вашиот компјутер и на вашиот мобилен телефон.",
    "Search contacts" : "Пребарување контакти",
    "Reset search" : "Ресетирај пребарување",
    "Search contacts …" : "Пребарување контакти ...",
    "Could not load your contacts" : "Неможат да се вчитаат вашите контакти",
    "No contacts found" : "Не се пронајдени контакти",
    "Show all contacts" : "Прикажи ги сите контакти",
    "Install the Contacts app" : "Инсталирај апликација за контакти",
    "Loading your contacts …" : "Вчитување на вашите контакти ...",
    "Looking for {term} …" : "Пребарување за {term} …",
    "Search for {name} only" : "Пребарај само за {name}",
    "Start typing to search" : "Напишете нешто за пребарување",
    "Loading more results …" : "Вчитување на повеќе резултати ...",
    "Load more results" : "Вчитај повеќе резултати",
    "Search" : "Барај",
    "No results for {query}" : "Нема резултати за {query}",
    "Press Enter to start searching" : "Притисни Enter за започне пребарувањето",
    "An error occurred while searching for {type}" : "Настана грешка при пребарување за {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Внесете најмалку {minSearchLength} карактер за да пребарувате","Внесете најмалку {minSearchLength} карактери или повеќе за да пребарувате"],
    "Forgot password?" : "Заборавена лозинка?",
    "Back to login form" : "Врати се на формата за најавување",
    "Back" : "Назад",
    "Login form is disabled." : "Формата за најава е оневозможена.",
    "Edit Profile" : "Уреди профил",
    "The headline and about sections will show up here" : "Насловот и за секциите ќе се појават овде",
    "You have not added any info yet" : "Сè уште немате додадено никакви информации",
    "{user} has not added any info yet" : "{user} нема додадено никакви информации",
    "Search apps, files, tags, messages" : "Барај апликации, датотеки, ознаки, пораки",
    "Search {types} …" : "Пребарување {types} …",
    "Apps and Settings" : "Апликации и параметри",
    "Date" : "Датум",
    "Today" : "Денес",
    "Last 7 days" : "Предходни 7 дена",
    "Last 30 days" : "Предходни 30 дена",
    "This year" : "Оваа година",
    "Last year" : "Предходна година",
    "Not found" : "Не е пронајдено",
    "People" : "Луѓе",
    "Search in" : "Барај во",
    "Searching …" : "Пребарување ...",
    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Помеѓу ${this.dateFilter.startFrom.toLocaleDateString()} и ${this.dateFilter.endAt.toLocaleDateString()}",
    "This browser is not supported" : "Овој прелистувач не е поддржан",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашиот прелистувач не е поддржан. Надградете на понова или поддржана верзија.",
    "Continue with this unsupported browser" : "Продолжете со овој неподдржан прелистувач",
    "Supported versions" : "Поддржани верзии",
    "{name} version {version} and above" : "{name} верзија {version} и понови",
    "Settings menu" : "Мени за параметри",
    "Avatar of {displayName}" : "Аватар на {displayName}",
    "No" : "Не",
    "Yes" : "Да",
    "Choose {file}" : "Избери {file}",
    "Choose" : "Избери",
    "Copy to {target}" : "Копирај во {target}",
    "Copy" : "Копирај",
    "Move to {target}" : "Премести во {target}",
    "Move" : "Премести",
    "OK" : "Добро",
    "Error loading message template: {error}" : "Грешка при вчитување на образецот за порака: {error}",
    "read-only" : "само за читање",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} датотека со конфликт","{count} датотеки со конфликти"],
    "One file conflict" : "Конфликт со една датотека",
    "New Files" : "Нови датотеки",
    "Already existing files" : "Постоечки датотеки",
    "Which files do you want to keep?" : "Кои датотеки сакате да ги задржите?",
    "If you select both versions, the copied file will have a number added to its name." : "Ако ги одберете и двете верзии, копираната датотека ќе има број додаден на нејзиното име.",
    "Cancel" : "Откажи",
    "Continue" : "Продолжи",
    "(all selected)" : "(сите одбрани)",
    "({count} selected)" : "({count} одбраните)",
    "Error loading file exists template" : "Грешка при вчитување на датотеката, шаблонот постои ",
    "Saving …" : "Зачувува ...",
    "seconds ago" : "пред неколку секунди",
    "Connection to server lost" : "Изгубена е врската со серверот",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Проблем при вчитување на страницата, превчитување за %n секунда","Проблем при вчитување на страницата, превчитување за %n секунди"],
    "Add to a project" : "Додади во проект",
    "Show details" : "Прикажи детали",
    "Hide details" : "Сокриј детали",
    "Rename project" : "Преименувај проект",
    "Failed to rename the project" : "Неуспешно преименување на проектот",
    "Failed to create a project" : "Неуспешно креирање на проектот",
    "Failed to add the item to the project" : "Неуспешно додавање на ставката во проектот",
    "Connect items to a project to make them easier to find" : "Поврзете ги датотеките и папките во проект за да може полесно да ги пронаоѓате",
    "Type to search for existing projects" : "Пребарувај за постоечки проекти",
    "New in" : "Ново во",
    "View changelog" : "Види ги промените",
    "Very weak password" : "Многу слаба лозинка",
    "Weak password" : "Слаба лозинка",
    "So-so password" : "Така така лозинка",
    "Good password" : "Добра лозинка",
    "Strong password" : "Јака лозинка",
    "No action available" : "Нема акции достапни",
    "Error fetching contact actions" : "Грешка при преземање на контакт",
    "Close \"{dialogTitle}\" dialog" : "Затвори \"{dialogTitle}\"",
    "Non-existing tag #{tag}" : "Непостоечка ознака #{tag}",
    "Restricted" : "Ограничена",
    "Invisible" : "Невидливо",
    "Delete" : "Избриши",
    "Rename" : "Преименувај",
    "Collaborative tags" : "Колаборативна ознака",
    "No tags found" : "Не се пронајдени ознаки",
    "Personal" : "Лично",
    "Accounts" : "Сметки",
    "Apps" : "Аппликации",
    "Admin" : "Админ",
    "Help" : "Помош",
    "Access forbidden" : "Забранет пристап",
    "Profile not found" : "Профилот не е пронајден",
    "The profile does not exist." : "Профилот на постои",
    "Back to %s" : "Врати се на %s",
    "Page not found" : "Страницата не е пронајдена",
    "The page could not be found on the server or you may not be allowed to view it." : "Страната не е пронајдена на серверот или не ви е дозволен пристап.",
    "Too many requests" : "Премногу барања",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Има испратено премногу барање од вашата мрежа. Обидете се подоцна повторно или контактирајте го администраторот.",
    "Error" : "Грешка",
    "Previous" : "Претходно",
    "Internal Server Error" : "Внатрешна серверска грешка",
    "The server was unable to complete your request." : "Серверот не е во можност да го комплетира вашето брање.",
    "If this happens again, please send the technical details below to the server administrator." : "Доколку ова се случи повторно, ве молиме испрате технички детали на администраторот на серверот.",
    "More details can be found in the server log." : "Повеќе информации можат да се пронајдат во запискинот на серверот.",
    "Technical details" : "Технички детали",
    "Remote Address: %s" : "Далечинкска Адреса: %s",
    "Request ID: %s" : "Барање број: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Код: %s",
    "Message: %s" : "Порака: %s",
    "File: %s" : "Датотека: %s",
    "Line: %s" : "Линија: %s",
    "Trace" : "Следи",
    "Security warning" : "Безбедносно предупредување",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Вашиот директориум со податоци и датотеки се веројатно достапни преку интенернт поради што .htaccess датотеката не функционира.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информации како правилно да го конфигурирате вашиот сервер, ве молиме погледнете ја <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацијата</a>.",
    "Create an <strong>admin account</strong>" : "Направете <strong>администраторска сметка</strong>",
    "Show password" : "Прикажи лозинка",
    "Toggle password visibility" : "Вклучи видливост на лозинки",
    "Storage & database" : "Складиште & база на податоци",
    "Data folder" : "Фолдер со податоци",
    "Configure the database" : "Конфигурирај ја базата",
    "Only %s is available." : "Само %s е достапно.",
    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте дополнителни PHP додатоци за да можете да изберете друг вид на база на податоци.",
    "For more details check out the documentation." : "За повеќе детали проверете ја документацијата.",
    "Database password" : "Лозинка на база",
    "Database name" : "Име на база",
    "Database tablespace" : "Табела во базата на податоци",
    "Database host" : "Сервер со база",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Ве молиме, наведете го бројот на портата, заедно со името на серверот (на пример, localhost:5432).",
    "Performance warning" : "Предупредување за перформансите",
    "You chose SQLite as database." : "Вие избравте SQLite како база на податоци.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за минимални и развојни цели. За користење, препорачуваме различен начин за база на податоци.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ако користите клиент за синхронизација на датотеки, SQLite не е препорачливо.",
    "Install" : "Инсталирај",
    "Installing …" : "Инсталирање ...",
    "Need help?" : "Ви треба помош?",
    "See the documentation" : "Види ја документацијата",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Изгледа дека се обидувате да го преинсталирате Nextcloud. Како и да е, датотеката CAN_INSTALL недостасува во вашата конфигурациона папка. Креирајте празна датотека CAN_INSTALL во конфигурационата папка за да продолжите.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Неможе да се отстрани CAN_INSTALL датотеката од конфигурациската папка. Избришете ја рачно.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "За оваа апликација да работи исправно потребна е JavaScript. Ве молиме {linkstart}овозможете JavaScript{linkend} и превчитајте ја страницата.",
    "Skip to main content" : "Оди до главната содржина",
    "Skip to navigation of app" : "Оди до навигацијата на апликацијата",
    "Go to %s" : "Оди до %s",
    "Get your own free account" : "Креирајте ваша сметка",
    "Connect to your account" : "Поврзани со вашата сметка",
    "Please log in before granting %1$s access to your %2$s account." : "Ве молиме најавете се пред да доделите пристап на %1$s во вашата %2$s сметка.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Доколку не се обидувате да додадете нов уред, некој се обидува да ве надитри и да обезбеди пристап до вашите податоци. Во тој случај не продолжувајте понатаму и веднаш контактирајте го администраторот.",
    "App password" : "Лозинка за апликација",
    "Grant access" : "Дозволи пристап",
    "Alternative log in using app password" : "Алтернативен начин на најава со користење на лозинка за апликација",
    "Account access" : "Пристап до сметка",
    "Currently logged in as %1$s (%2$s)." : "Најавени сте како %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Ќе доделите пристап на %1$s во вашата %2$s сметка.",
    "Account connected" : "Сметката е поврзана",
    "Your client should now be connected!" : "Вашиот клиент сега треба да биде поврзан!",
    "You can close this window." : "Можете да го затворите овој прозорец.",
    "This share is password-protected" : "Ова споделување е заштитено со лозинка",
    "The password is wrong or expired. Please try again or request a new one." : "Лозинката е погрешна или е истечена. Ве молиме обидете се повторно или побарајте нова лозинка.",
    "Please type in your email address to request a temporary password" : "Внесете ја вашата е-пошта адреса за да добиете привремена лозинка",
    "Email address" : "Е-пошта адреси",
    "Password sent!" : "Лозинка е испратена!",
    "You are not authorized to request a password for this share" : "Не сте авторизиран за да побарате лозинка за ова споделување",
    "Two-factor authentication" : "Двофакторна автентикација",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Подобрете ја сигурноста на вашата сметка. Изберете двофакторна автентификација:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Неможе да се вчита овозможениот начини за дво-факторна автентификација. Ве молиме контактирајте го администраторот.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двофакторна автентикација е задолжителна но не е поставена на вашата сметка. Контактирајте го администраторот.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двофакторна автентикација е задолжителна но не е поставена на вашата сметка. Ве молиме продолжете за да поставете двофакторна автентикација.",
    "Set up two-factor authentication" : "Постави двофакторна автентикација",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двофакторна автентикација е задолжителна но не е поставена на вашата сметка. Користете еден од резервните кодови за да се најавите или контактирате го администраторот за помош.",
    "Use backup code" : "Искористи резервен код",
    "Cancel login" : "Откажи најава",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Подобрете ја сигурноста на вашата сметка. Изберете кој провајдер сакате да го поставите:",
    "Error while validating your second factor" : "Грешка при верификација на вториот фактор",
    "Access through untrusted domain" : "Пристап преку недоверлив домен.",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Ве молиме контактирајте го администраторот. Доколку сте администратор, променете го \"trusted_domains\" подесувањето во config/config.php како во примерот config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Дополнителни информации како да го конфигурирате ова може да најдете во %1$sдокоментацијата%2$s.",
    "App update required" : "Потребна е надградба на апликацијата",
    "%1$s will be updated to version %2$s" : "%1$s ќе биде ажурирана во верзија %2$s",
    "The following apps will be updated:" : "Следните апликации ќе бидат ажурирани:",
    "These incompatible apps will be disabled:" : "Овие апликации се некомпатабилни и ќе бидат оневозможени:",
    "The theme %s has been disabled." : "Темета %s е оневозможена.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ве молиме осигурајте се дека базата на податоци, конфигурациониот директориум и директориумот со податоци се безбедно копирани  пред да продолжите.",
    "Start update" : "Започни ја надградбата",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "За да избегнете тајм аут за големи инсталации, можете да ја извршите следнава команда во директориумот за инсталација:",
    "Detailed logs" : "Детални записи",
    "Update needed" : "Потребно е ажутирање",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помош, прочитајте ја <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацијата</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Знам дека има ризик ако продолжам со ажурирањето преку веб-интерфејс, и да застане во тајм аут и може да предизвика загуба на податоци, но имам резервна копија и знам како да ја вратам мојата истанца во случај на дефект.",
    "Upgrade via web on my own risk" : "Надоградба преку веб-интерфејс на сопствен ризик",
    "Maintenance mode" : "Мод за одржување",
    "This %s instance is currently in maintenance mode, which may take a while." : "Истанцата %s моментално е во режим на одржување, што значи дека може да потрае некое време.",
    "This page will refresh itself when the instance is available again." : "Оваа веб страница ќе се рефрешира кога истанцата ќе биде повторно достапна.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте го вашиот систем администратор до колку оваа порака продолжи да се појавува или пак се појавува ненадејно.",
    "Please try again" : "Ве молиме обидете се повторно",
    "The user limit of this instance is reached." : "Лимитот на корисници на оваа истанца е исполнет.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Вашиот веб сервер не е правилно поставен за разрешаување на \"{url}\". Ова најверојатно е поврзано со конфигурацијата на веб-серверот или не е ажуриран за директен пристап до оваа папка. Ве молиме, споредете ја вашата конфигурација дали е во согласност со правилата за пренасочување во \".htaccess\" за Apache или во документацијата за  Nginx на {linkstart}страната со документација{linkend}. На Nginx тоа се најчето линиите што започнуваат со \"location ~\" што им треба ажурирање.",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Вашиот веб сервер не е правилно поставен за испорака на .woff2 датотеки. Ова обично е проблем со конфигурацијата на Nginx. За Nextcloud 15 исто така е потребно да се испорачуваат .woff2 датотеки. Споредете ја вашата конфигурација на Nginx со препорачаната конфигурација во нашата {linkstart}документација{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP се чини дека не е правилно поставена за да испраќа барања до променливите на околината на системот. Тестот со getenv(\"PATH\") враќа само празен одговор.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Ве молиме проверете ја {linkstart}документацијата за инсталација ↗{linkend} за конфигурационите PHP белешки и PHP конфигурацијата на вашиот сервер, особено кога користите php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Антивирана е конфигурација која е само за чирање. Ова спречува поставување на некои конфигурации преку веб-интерфејсот. Понатаму, датотеката треба да се пребрише рачно за секое ажурирање.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Вашата база на податоци не работи со нивото на изолација со \"READ COMMITTED\". Ова може да предизвика проблеми кога повеќе дејства се извршуваат паралелно.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Недостасува PHP модулот \"fileinfo\". Препорачливо е да го овозможите овој додаток за да ги добиете најдобрите резултати со детекција на MIME видот.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Заклучување на активна датотека е оневозможено, ова може да доведе до проблеми со условите на синхронизација. Овозможете \"filelocking.enabled\" во config.php за да ги избегнете овие проблеми. Видете во  {linkstart}документацијата ↗{linkend} за повеќе информации.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Не е возможно извршување на cron позадинските задачи преку CLI. Се појавија следниве технички грешки:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Од последенио пат како се извршени позадинските задачи се поминати {relativeTime}. Изгледа нешто не е во ред. {linkstart}Проверете ги параметрите за позадинските задачи ↗{linkend}.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Овој опслужувач нема работна Интернет врска. Ова значи дека некои опции како што е монтирање на надворешни складишта, известувања за ажурирање или инсталации на апликации од 3-ти лица нема да работат. Пристапот на датотеки од далечина и праќање на пораки за известувања може исто така да не работат. Ви советуваме да овозможите Интернет врска за овој опслужувач ако сакате да ги имате сите опции. ",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не е конфигурирана мемориjа за кеширање. За да ги подобрите перформансите, конфигурирајте memcache, доколку е можно. Дополнителни информации може да се најдат во {linkstart}документацијата{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Моненталната верзија на PHP е {version}. Ажурирајте ја PHP верзијата да ги искористите предностите од {linkstart}перформанси и безбедносни ажурирања обезбедени од групацијата PHP ↗{linkend} штом вашата дистрибуција го поддржува.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Некои датотеки не ја поминаа проверката на интегритет. Дополнителни информации за тоа како да се реши ова прашање може да се најде во  {linkstart1}документацијата↗{linkend}. ({linkstart2}Листа на невалидни датотеки…{linkend} / {linkstart3}Повторно скенирање…{linkend})",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP функцијата \"set_time_limit\" не е достапна. Ова може да резултира со запирање на скриптите во извршувањето, и грешки во вашата инсталација. Овозможувањето на оваа функција е препорачлива.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Недостасува индексот \"{indexName}\" во табелата \"{tableName}\".",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Во базата недостасуваат некој индекси. Поради фактот што додавањето индекси во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-indices\" ќе бидат додадени оние индекси што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени индексите, барањата во табелите ќе биде многу побрзо.",
    "Missing primary key on table \"{tableName}\"." : "Недостасува примарен клуч во табелата \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Во базата недостасуваат некој примарни клучеви. Поради фактот што додавањето на примарни клучеви во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-primary-keys\" ќе бидат додадени оние примарни клучеви што недостасуваат и инстанцата непречено ќе работи.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Недостасува опција во колоната \"{columnName}\" во табелата \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Во базата недостасуваат некој опционални колони. Поради фактот што додавањето колони во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-columns\" ќе бидат додадени оние колони што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени колоните, некој карактеристики ќе се подобрат и можат да ја подобрат употребата и безбедноста.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "На оваа истанца недостасуваат некој препорачливи PHP модули. За подобри перформанси и подобра компатибилност, се препорачува да ги инсталирате.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модулот php-imagick во оваа истанца не поддржува SVG датотеки. За подобра компатибилност се препорачува да се инсталира.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Моментално се користи SQLite како база за податоци. За користење, препорачуваме различен начин за база на податоци.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Ова особено е препорачливо кога се користи клиент за синхронизација.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "За да мигрирате во друга база на податоци, користете ја алатката во командната линија: 'occ db:convert-type', или погледнете во {linkstart}документацијата ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "Меморијата за PHP е под препорачаната вредност од 512MB.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Некој папки со апликации не се сопственост на корисникот на веб серверот. Ова може да биде случај ако апликациите се инсталирани рачно. Проверете ги дозволите на следниве папки со апликации:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL се користи како база на податоци, но не поддржува 4-бајтни карактери. За да можете да ракувате со 4-бајтни карактери (како емотикони) без проблеми во имиња на датотеки или коментари, се препорачува да се овозможи поддршка од 4-бајти во MySQL. За повеќе детали прочитајте во {linkstart}документација{linkstart}.",
    "Account name or email" : "Корисничко име или е-пошта",
    "Wrong username or password." : "Погрешно корисничко име или лозинка.",
    "User disabled" : "Корисникот е оневозможен",
    "Username or email" : "Корисничко име или е-пошта",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Порака за ресетирање на лозинката е испратена на е-пошта на оваа сметка. Доколку не сте ја добиле, проверете во spam/junk папката или прашајте го вашиот локален администратор за помош.",
    "If it is not there ask your local administrator." : "Доколку не е таму, прашајте го вашиот локален администратор.",
    "Start search" : "Започни пребарување",
    "Press enter to start searching" : "Притисни Enter за започне пребарувањето",
    "Open settings menu" : "Мени за параметри",
    "Settings" : "Параметри",
    "Show all contacts …" : "Прикажи ги сите контакти ...",
    "No files in here" : "Тука нема датотеки",
    "New folder" : "Нова папка",
    "No more subfolders in here" : "Нема повеќе поддиректориуми тука",
    "Name" : "Име",
    "Size" : "Големина",
    "Modified" : "Изменето",
    "\"{name}\" is an invalid file name." : "\"{name}\" е невалидно име за датотека.",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "\"/\" is not allowed inside a file name." : "\"/\" не е дозволено во името.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" не е дозволен вид на датотека",
    "{newName} already exists" : "{newName} веќе постои",
    "Error loading file picker template: {error}" : "Грешка при вчитување на образецот за одбирач на датотеки: {error}",
    "Show list view" : "Прикажи поглед во листа",
    "Show grid view" : "Прикажи поглед во мрежа",
    "Pending" : "Чекање",
    "Home" : "Дома",
    "Copy to {folder}" : "Копирај во {folder}",
    "Move to {folder}" : "Премести во {folder}",
    "Authentication required" : "Потребна е автентификација",
    "This action requires you to confirm your password" : "За оваа акција потребно е да ја потврдите вашата лозинка",
    "Confirm" : "Потврди",
    "Failed to authenticate, try again" : "Неуспешна автентификација, обидете се повторно",
    "Users" : "Корисници",
    "The page could not be found on the server." : "Страницата не е пронајдена на серверот.",
    "Username" : "Корисничко име",
    "Database user" : "Корисник на база",
    "Confirm your password" : "Потврдете ја вашата лозинка",
    "App token" : "App token",
    "Alternative log in using app token" : "Алтернативен начин на најава со користење на токен",
    "Please use the command line updater because you have a big instance with more than 50 users." : "Ве молиме користете ја командната линија за ажурирање бидејќи имате голема истанца со повеќе од 50 корисници.",
    "Avatar of {fullName}" : "Аватар на {fullName}"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
